@@ -5,7 +5,13 @@ import maisaedu_utilities_prefect.environment
 import maisaedu_utilities_prefect.notification
 import maisaedu_utilities_prefect.constants
 
-from .secrets import download_secret, upload_secret, setup_secrets, refresh_secrets
+from .secrets import (
+    download_secret,
+    upload_secret,
+    setup_secrets,
+    refresh_secrets,
+    async_setup_secrets,
+)
 from .dw import get_dsn, get_dsn_as_url, query_file, query_str
 from .notification import notifier_factory, send_teams_alert_on_failure
 from .environment import get_env
