@@ -97,12 +97,12 @@ def get_all_deals_v1(hapikey, app_private_token, properties, extraparams):
             yield resp["deals"]
             hasmore = resp["hasMore"]
             offset = resp["offset"]
-            yield resp["deals"]
             attempts = 0
         except KeyError as e:
             attempts += 1
             sleep(10)
             if attempts > 2:
+                prefect.get_run_logger().error(resp)
                 raise Exception(e)
     return data
 
@@ -120,13 +120,21 @@ def get_all_deals_v1_recent_modified(
         )
         try:
             yield resp["results"]
+            lasttimestamp = list(resp["results"])[0]["properties"][
+                "hs_lastmodifieddate"
+            ]["timestamp"]
+            attempts = 0
             hasmore = resp["hasMore"]
             offset = resp["offset"]
-            yield resp["results"]
             attempts = 0
         except KeyError as e:
+            if offset >= 10000:
+                since = str(lasttimestamp)
+                offset = 0
+
             attempts += 1
             sleep(10)
             if attempts > 2:
+                prefect.get_run_logger().error(resp)
                 raise Exception(e)
     return data
