@@ -38,12 +38,9 @@ def get_events(
 
     url = url + parameters
 
-    try:
-        r = requests.get(url=url, headers=headers)
-        response_dict = json.loads(r.text)
-        return response_dict
-    except Exception as e:
-        print(e)
+    r = requests.get(url=url, headers=headers, timeout=5)
+    response_dict = json.loads(r.text)
+    return response_dict
 
 
 def get_all_email_events(
